==> nexi_xpay-2.1.0.zip: nexi_xpay/src/Form/RegenerateTokenForm.php <==
<?php

declare(strict_types=1);

namespace Drupal\nexi_xpay\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\Url;
use Drupal\nexi_xpay\Entity\NexiXpayTransactionInterface;

/**
 * Form controller for the regenerate token action.
 */
final class RegenerateTokenForm extends ConfirmFormBase {

  private NexiXpayTransactionInterface $transaction;

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'nexi_xpay_regenerate_token_form';
  }

  /**
   * @inheritDoc
   */
  public function buildForm(array $form, FormStateInterface $form_state, NexiXpayTransactionInterface $nexi_xpay_transaction = NULL): array {
    $this->transaction = $nexi_xpay_transaction;
    return parent::buildForm($form, $form_state);
  }

  /**
   * @inheritDoc
   */
  public function getQuestion(): TranslatableMarkup {
    return $this->t('Regenerate public token for transaction @id?', ['@id' => $this->transaction->id()]);
  }

  /**
   * @inheritDoc
   */
  public function getDescription(): TranslatableMarkup {
    return $this->t('This will invalidate the previous public payment link.');
  }

  /**
   * @inheritDoc
   */
  public function getCancelUrl(): Url {
    return Url::fromRoute('entity.nexi_xpay_transaction.collection');
  }

  /**
   * @inheritDoc
   */
  public function getConfirmText(): TranslatableMarkup {
    return $this->t('Regenerate token');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    // Regola richiesta: per ora ha senso rigenerare solo se pending.
    if ($this->transaction->getStatus() !== NexiXpayTransactionInterface::STATUS_PENDING) {
      $this->messenger()->addError($this->t('Token can be regenerated only when the transaction is pending.'));
      $form_state->setRedirectUrl($this->getCancelUrl());
      return;
    }

    // TODO: sviluppare un metodo unico per generare il token
    //      rif. 'src/Entity/NexiXpayTransaction.php'
    $plain = bin2hex(random_bytes(16));
    $this->transaction->set('public_token', $plain);
    $this->transaction->set('public_token_hash', hash('sha256', $plain));
    $this->transaction->save();

    $pay_url = Url::fromRoute('nexi_xpay.pay', [
      'nexi_xpay_transaction' => $this->transaction->id(),
    ], [
      'absolute' => TRUE,
      'query' => ['t' => $plain],
    ])->toString();

    $this->messenger()->addStatus($this->t('Token regenerated. New pay link: @url', ['@url' => $pay_url]));
    $form_state->setRedirectUrl($this->getCancelUrl());
  }

}

==> nexi_xpay-2.2.0.zip: nexi_xpay/src/Form/RegenerateTokenForm.php <==
<?php

declare(strict_types=1);

namespace Drupal\nexi_xpay\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\Url;
use Drupal\nexi_xpay\Entity\NexiXpayTransactionInterface;
use Drupal\nexi_xpay\Util\SecretGenerator;
use Random\RandomException;

/**
 * Form controller for the regenerate token action.
 */
final class RegenerateTokenForm extends ConfirmFormBase {

  private NexiXpayTransactionInterface $transaction;

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'nexi_xpay_regenerate_token_form';
  }

  /**
   * @inheritDoc
   */
  public function buildForm(array $form, FormStateInterface $form_state, NexiXpayTransactionInterface $nexi_xpay_transaction = NULL): array {
    $this->transaction = $nexi_xpay_transaction;
    return parent::buildForm($form, $form_state);
  }

  /**
   * @inheritDoc
   */
  public function getQuestion(): TranslatableMarkup {
    return $this->t('Regenerate public token for transaction @id?', ['@id' => $this->transaction->id()]);
  }

  /**
   * @inheritDoc
   */
  public function getDescription(): TranslatableMarkup {
    return $this->t('This will invalidate the previous public payment link.');
  }

  /**
   * @inheritDoc
   */
  public function getCancelUrl(): Url {
    return Url::fromRoute('entity.nexi_xpay_transaction.collection');
  }

  /**
   * @inheritDoc
   */
  public function getConfirmText(): TranslatableMarkup {
    return $this->t('Regenerate token');
  }

  /**
   * {@inheritdoc}
   * @throws RandomException|\Drupal\Core\Entity\EntityStorageException
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    // Regola richiesta: per ora ha senso rigenerare solo se pending.
    if ($this->transaction->getStatus() !== NexiXpayTransactionInterface::STATUS_PENDING) {
      $this->messenger()->addError($this->t('Token can be regenerated only when the transaction is pending.'));
      $form_state->setRedirectUrl($this->getCancelUrl());
      return;
    }

    $plain = SecretGenerator::generateHexSecretWithHash(16);
    $this->transaction->set('public_token', $plain['secret']);
    $this->transaction->set('public_token_hash', hash('sha256', $plain['hash']));
    $this->transaction->save();

    $pay_url = Url::fromRoute('nexi_xpay.pay', [
      'nexi_xpay_transaction' => $this->transaction->id(),
    ], [
      'absolute' => TRUE,
      'query' => ['t' => $plain],
    ])->toString();

    $this->messenger()->addStatus($this->t('Token regenerated. New pay link: @url', ['@url' => $pay_url]));
    $form_state->setRedirectUrl($this->getCancelUrl());
  }

}
